@@ -96,31 +96,32 @@ type V2PlatformMigrator interface {
 
 // FIXME: a lot of stuff is shared with MachineDeployment... might be useful to consolidate the shared stuff into another library/package/something
 type v2PlatformMigrator struct {
-	apiClient         *api.Client
-	flapsClient       *flaps.Client
-	gqlClient         graphql.Client
-	io                *iostreams.IOStreams
-	colorize          *iostreams.ColorScheme
-	leaseTimeout      time.Duration
-	leaseDelayBetween time.Duration
-	appCompact        *api.AppCompact
-	appFull           *api.App
-	appConfig         *appconfig.Config
-	configPath        string
-	autoscaleConfig   *api.AutoscalingConfig
-	volumeDestination string
-	processConfigs    map[string]*appconfig.ProcessConfig
-	img               string
-	appLock           string
-	releaseId         string
-	releaseVersion    int
-	oldAllocs         []*api.AllocationStatus
-	machineGuest      *api.MachineGuest
-	oldVmCounts       map[string]int
-	newMachinesInput  []*api.LaunchMachineInput
-	newMachines       machine.MachineSet
-	canAvoidDowntime  bool
-	recovery          recoveryState
+	apiClient               *api.Client
+	flapsClient             *flaps.Client
+	gqlClient               graphql.Client
+	io                      *iostreams.IOStreams
+	colorize                *iostreams.ColorScheme
+	leaseTimeout            time.Duration
+	leaseDelayBetween       time.Duration
+	appCompact              *api.AppCompact
+	appFull                 *api.App
+	appConfig               *appconfig.Config
+	configPath              string
+	autoscaleConfig         *api.AutoscalingConfig
+	volumeDestination       string
+	processConfigs          map[string]*appconfig.ProcessConfig
+	formattedProcessConfigs string
+	img                     string
+	appLock                 string
+	releaseId               string
+	releaseVersion          int
+	oldAllocs               []*api.AllocationStatus
+	machineGuest            *api.MachineGuest
+	oldVmCounts             map[string]int
+	newMachinesInput        []*api.LaunchMachineInput
+	newMachines             machine.MachineSet
+	canAvoidDowntime        bool
+	recovery                recoveryState
 }
 
 type recoveryState struct {
@@ -157,6 +158,7 @@ func NewV2PlatformMigrator(ctx context.Context, appName string) (V2PlatformMigra
 		return nil, err
 	}
 	processConfigs, err := appConfig.GetProcessConfigs()
+	formattedProcessConfigs := appConfig.FormatProcessNames()
 	if err != nil {
 		return nil, err
 	}
@@ -184,23 +186,24 @@ func NewV2PlatformMigrator(ctx context.Context, appName string) (V2PlatformMigra
 	leaseTimeout := 13 * time.Second
 	leaseDelayBetween := (leaseTimeout - 1*time.Second) / 3
 	migrator := &v2PlatformMigrator{
-		apiClient:         apiClient,
-		flapsClient:       flapsClient,
-		gqlClient:         apiClient.GenqClient,
-		io:                io,
-		colorize:          colorize,
-		leaseTimeout:      leaseTimeout,
-		leaseDelayBetween: leaseDelayBetween,
-		appCompact:        appCompact,
-		appFull:           appFull,
-		appConfig:         appConfig,
-		autoscaleConfig:   autoscaleConfig,
-		volumeDestination: appConfig.MountsDestination(),
-		processConfigs:    processConfigs,
-		img:               img,
-		oldAllocs:         allocs,
-		machineGuest:      machineGuest,
-		canAvoidDowntime:  true,
+		apiClient:               apiClient,
+		flapsClient:             flapsClient,
+		gqlClient:               apiClient.GenqClient,
+		io:                      io,
+		colorize:                colorize,
+		leaseTimeout:            leaseTimeout,
+		leaseDelayBetween:       leaseDelayBetween,
+		appCompact:              appCompact,
+		appFull:                 appFull,
+		appConfig:               appConfig,
+		autoscaleConfig:         autoscaleConfig,
+		volumeDestination:       appConfig.MountsDestination(),
+		processConfigs:          processConfigs,
+		formattedProcessConfigs: formattedProcessConfigs,
+		img:                     img,
+		oldAllocs:               allocs,
+		machineGuest:            machineGuest,
+		canAvoidDowntime:        true,
 		recovery: recoveryState{
 			platformVersion: appFull.PlatformVersion,
 		},
@@ -226,7 +229,6 @@ func NewV2PlatformMigrator(ctx context.Context, appName string) (V2PlatformMigra
 }
 
 func (m *v2PlatformMigrator) rollback(ctx context.Context, tb *render.TextBlock) error {
-
 	defer func() {
 		if m.recovery.appLocked {
 			tb.Detail("Unlocking application")
@@ -254,7 +256,7 @@ func (m *v2PlatformMigrator) rollback(ctx context.Context, tb *render.TextBlock)
 				ID:    mach.ID,
 				Kill:  true,
 			}
-			err := m.flapsClient.Destroy(ctx, input)
+			err := m.flapsClient.Destroy(ctx, input, mach.LeaseNonce)
 			if err != nil {
 				return err
 			}
@@ -290,7 +292,6 @@ func (m *v2PlatformMigrator) rollback(ctx context.Context, tb *render.TextBlock)
 }
 
 func (m *v2PlatformMigrator) Migrate(ctx context.Context) (err error) {
-
 	ctx = flaps.NewContext(ctx, m.flapsClient)
 
 	tb := render.NewTextBlock(ctx, fmt.Sprintf("Migrating %s to the V2 platform", m.appCompact.Name))
@@ -499,10 +500,9 @@ func (m *v2PlatformMigrator) validateVolumes(ctx context.Context) error {
 }
 
 func (m *v2PlatformMigrator) validateProcessGroupsOnAllocs(ctx context.Context) error {
-	knownProcGroupsStr := strings.Join(lo.Keys(m.processConfigs), ", ")
 	for _, a := range m.oldAllocs {
 		if _, exists := m.processConfigs[a.TaskName]; !exists {
-			return fmt.Errorf("alloc %s has process group '%s' that is not present in app configuration fly.toml; known process groups are: %s", a.IDShort, a.TaskName, knownProcGroupsStr)
+			return fmt.Errorf("alloc %s has process group '%s' that is not present in app configuration fly.toml; known process groups are: %s", a.IDShort, a.TaskName, m.formattedProcessConfigs)
 		}
 	}
 	return nil
@@ -558,7 +558,6 @@ func (m *v2PlatformMigrator) createRelease(ctx context.Context) error {
 }
 
 func (m *v2PlatformMigrator) resolveProcessGroups(ctx context.Context) {
-
 	m.oldVmCounts = map[string]int{}
 	for _, alloc := range m.oldAllocs {
 		m.oldVmCounts[alloc.TaskName] += 1
@@ -566,7 +565,6 @@ func (m *v2PlatformMigrator) resolveProcessGroups(ctx context.Context) {
 }
 
 func (m *v2PlatformMigrator) scaleNomadToZero(ctx context.Context) error {
-
 	input := gql.SetVMCountInput{
 		AppId:  m.appConfig.AppName,
 		LockId: m.appLock,
@@ -592,7 +590,6 @@ func (m *v2PlatformMigrator) scaleNomadToZero(ctx context.Context) error {
 }
 
 func (m *v2PlatformMigrator) waitForAllocsZero(ctx context.Context) error {
-
 	s := spinner.New(spinner.CharSets[9], 200*time.Millisecond)
 	s.Writer = m.io.ErrOut
 	s.Prefix = fmt.Sprintf("Waiting for nomad allocs for '%s' to be destroyed ", m.appCompact.Name)
@@ -815,7 +812,6 @@ func (m *v2PlatformMigrator) determineConfigPath(ctx context.Context) error {
 }
 
 func (m *v2PlatformMigrator) ConfirmChanges(ctx context.Context) (bool, error) {
-
 	numAllocs := len(m.oldAllocs)
 
 	fmt.Fprintf(m.io.Out, "This migration process will do the following, in order:\n")
@@ -885,12 +881,10 @@ func determineAppConfigForMachines(ctx context.Context) (*appconfig.Config, erro
 }
 
 func determineVmSpecs(vmSize api.VMSize) (*api.MachineGuest, error) {
-
 	preset := strings.Replace(vmSize.Name, "dedicated-cpu", "performance", 1)
 
 	guest := &api.MachineGuest{}
 	err := guest.SetSize(preset)
-
 	if err != nil {
 		return nil, fmt.Errorf("nomad VM definition incompatible with machines API: %w", err)
 	}
