@@ -60,6 +60,7 @@ sets the size as the number of gigabytes the volume will consume.`
 			Name:        "snapshot-id",
 			Description: "Create volume from a specified snapshot",
 		},
+		flag.Yes(),
 	)
 
 	return cmd
@@ -79,8 +80,13 @@ func runCreate(ctx context.Context) error {
 		return err
 	}
 
-	var region *api.Region
+	if confirm, err := confirmVolumeCreate(ctx, appName); err != nil {
+		return err
+	} else if !confirm {
+		return nil
+	}
 
+	var region *api.Region
 	if region, err = prompt.Region(ctx, !app.Organization.PaidPlan, prompt.RegionParams{
 		Message: "",
 	}); err != nil {
@@ -115,3 +121,35 @@ func runCreate(ctx context.Context) error {
 
 	return printVolume(out, volume)
 }
+
+func confirmVolumeCreate(ctx context.Context, appName string) (bool, error) {
+	var volumeName = flag.FirstArg(ctx)
+
+	// If the Yes flag has been supplied we skip the warning entirely, so no
+	// need to query for the set of volumes
+	if flag.GetYes(ctx) {
+		return true, nil
+	}
+
+	// If we have more than 0 volues with this name already, return early
+	if matches, err := countVolumesMatchingName(ctx, appName, volumeName); err != nil {
+		return false, err
+	} else if matches > 0 {
+		return true, nil
+	}
+
+	io := iostreams.FromContext(ctx)
+	colorize := io.ColorScheme()
+
+	const msg = "Warning! Individual volumes are pinned to individual hosts. You should create two or more volumes per application. You will have downtime if you only create one. Learn more at https://fly.io/docs/reference/volumes/"
+	fmt.Fprintln(io.ErrOut, colorize.Red(msg))
+
+	switch confirmed, err := prompt.Confirm(ctx, "Do you still want to use the volumes feature?"); {
+	case err == nil:
+		return confirmed, nil
+	case prompt.IsNonInteractive(err):
+		return false, prompt.NonInteractiveError("yes flag must be specified when not running interactively")
+	default:
+		return false, err
+	}
+}
